# Copyright (C) 2008-2013 Zentyal S.L.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License, version 2, as
# published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

use strict;
use warnings;

package EBox::RemoteServices::CGI::Backup::DownloadRemoteBackup;

use base qw(EBox::CGI::ClientBase);

use EBox::RemoteServices::Backup;
use EBox::Gettext;
use EBox::Exceptions::Internal;

use Cwd qw(realpath);

sub new # (error=?, msg=?, cgi=?)
{
    my $class = shift;
    my $self = $class->SUPER::new( @_);
    $self->{errorchain} = "RemoteServices/Backup/Index";
    bless($self, $class);
    return $self;
}

# Method: _print
#
#      Print directly the file to download
#
# Overrides:
#
#      <EBox::CGI::Base::_print>
#
sub _print
{
    my ($self) = @_;
    if ( $self->{error} ) {
        $self->SUPER::_print;
        return;
    }

    my $name   = $self->param('name');
    my $backup = new EBox::RemoteServices::Backup();
    my $tmpFile = $backup->downloadRemoteBackup($name);

    open (my $fh, "<:raw", $tmpFile) or
            throw EBox::Exceptions::Internal('Could not open backup file.');
        Plack::Util::set_io_path($fh, Cwd::realpath($tmpFile));

    my $response = $self->response();
    $response->status(200);
    $response->content_type('application/x-tar');
    $response->header('Content-Disposition' => 'attachment; filename="' . "$name.tar" . '"');
    $response->body($fh);
}

sub requiredParameters
{
  return [qw(name)];
}

1;
