# Copyright (C) 2012-2014 Zentyal S.L.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License, version 2, as
# published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

package EBox::Reporter::Squid;

# Class: EBox::Reporter::Squid
#
#      Perform the squid consolidation
#

use warnings;
use strict;

use base 'EBox::Reporter::Base';

# Method: module
#
# Overrides:
#
#      <EBox::Reporter::Base::module>
#
sub module
{
    return 'squid';
}

# Method: name
#
# Overrides:
#
#      <EBox::Reporter::Base::name>
#
sub name
{
    return 'squid_access';
}

# Group: Protected methods

# Method: _consolidate
#
# Overrides:
#
#     <EBox::Exceptions::Reporter::Base::_consolidate>
#
sub _consolidate
{
    my ($self, $begin, $end) = @_;

    my $res = $self->{db}->query_hash(
        { select => $self->_hourSQLStr() . ','
                    . q{rfc931 AS username, remotehost AS ip, domain, event = 'accepted' AS accepted, code,
                        SUM(bytes) AS bytes, COUNT(event) AS hits, filterCategory as categories},
          from   => $self->name(),
          where  => $self->_rangeSQLStr($begin, $end),
          group  => $self->_groupSQLStr() . ', username, ip, domain, accepted, code'
         });

    # Split the categories into an array
    foreach my $entry (@{$res}) {
        my @categories = split(/, /, $entry->{categories});
        $entry->{categories} = \@categories;
    }

    return $res;
}

# Method: _booleanFields
#
# Overrides:
#
#     <EBox::Reporter::Base>
#
sub _booleanFields
{
    return [ 'accepted' ]
}

1;
